//////////////////////////////////////////////////////////////////////////////
//
// "Embedded C Programming: Techniques and Applications of C and PIC MCUs"
// by Mark Siegusmund
//
// Exercise 22-1 #1 SECONDARY
//
// This communicates with another E3 running the 'EX 22-1-1a.c' file.
//
// Receive commands over RS232, handle them and send response
//
//////////////////////////////////////////////////////////////////////////////

#include <e3.h>

#include "comms.h"

void main(void)
{
   packet_t p;
   
   setup_adc(ADC_CLOCK_INTERNAL | ADC_TAD_MUL_2);
   setup_adc_ports(sAN4);   
   set_adc_channel(4);
   
   for(;;)
   {
      if (CommsRxPacket(&p))
      {
         switch(p.cmd)
         {
            case SET_LEDS:
               p.cmd |= 0x80;
               // turn on
               if ((p.payload[0] & LED_BITMAP_RED) == LED_BITMAP_RED) output_high(PIN_C3);
               if ((p.payload[0] & LED_BITMAP_YELLOW) == LED_BITMAP_YELLOW) output_high(PIN_C4);
               if ((p.payload[0] & LED_BITMAP_GREEN) == LED_BITMAP_GREEN) output_high(PIN_C6);
               // turn off
               if ((p.payload[1] & LED_BITMAP_RED) == LED_BITMAP_RED) output_low(PIN_C3);
               if ((p.payload[1] & LED_BITMAP_YELLOW) == LED_BITMAP_YELLOW) output_low(PIN_C4);
               if ((p.payload[1] & LED_BITMAP_GREEN) == LED_BITMAP_GREEN) output_low(PIN_C6);               
               break;

            case WRITE_EE:
               p.cmd |= 0x80;
               write_eeprom(p.payload[0], p.payload[1]);
               break;

            case READ_EE:
               p.cmd |= 0x80;
               p.payload[0] = read_eeprom(p.payload[0]);
               break;

            case READ_BUTTONS:
               p.cmd |= 0x80;
               p.payload[0] = 0;
               if (!input(PIN_C1)) p.payload[0] |= 1;
               if (!input(PIN_C2)) p.payload[0] |= 2;
               break;

            case GET_ADC:
               p.cmd |= 0x80;
               p.payload[0] = read_adc();
               break;
            
            default:
               p.cmd = UNKNOWN_COMMAND;
               break;
         }
         
         CommsTxPacket(&p);
      }
   }
}
